/*---------------------------------------------------------------------------------------------------*\
|   PROGRAM NAME:prev_pat_keys.sas                                                                    |
|				                                                                                              |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Version: Revised 1.0                                                                              |
|   Date: November 26, 2015                                                                           |
|                                                                                                     |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Program inputs:                                                                                   |
|       Prevalent_Patients table                                                                      |
|   Program outputs:                                                                                  |
|	      CovKey value per PatKey                                                                       | 
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Contact:                                                                                          |
|       Mini-Sentinel Coordinating Center                                                             |
|       info@mini-sentinel.org                                                                        |
\*---------------------------------------------------------------------------------------------------*/

/* MOD: 10/08/15 -MR: */
/*                   - Replace &CovKeyStrLength with global parameter &DP_NumYears */
/* MOD: 10/22/15 -MR: MODIFY TO CALL FMCP NUMLENGTH FUNCTION WITHIN A DATA _NULL_ */
/* MOD: 12/07/15 -MR: Add CovKeyDrugAndMed */

** TASK SUMMARY ;
** ------------- ;
** Use Prevalent_Patients table
** Create CovKeyDrug and CovKeyMed with values that indicates for DP StartYear through DP EndYear all DrugCov and MedCov per patient;
%** Determine length in bytes to hold the numeric coverage string key value: Take all filled bits as 1s, convert to decimal, and
*** call function to return minimal number of bytes required;
%*let CovKeyLen=%sysfunc(NumLength(%sysfunc(inputn(%sysfunc(repeat(1,%eval(&DP_NumYears.-1))),binary&DP_NumYears..))));
data _null_;
  CovKeyLen = NumLength(input(repeat('1',%eval(&DP_NumYears.-1)),binary&DP_NumYears..));
  call symputx('CovKeyLen',CovKeyLen);
run ;
%put &=CovKeyLen;

data PrevPatsKey (keep=PatKey CovKeyDrug CovKeyMed CovKeyDrugAndMed sortedby=PatKey);
  length CovKeyDrug CovKeyMed CovKeyDrugAndMed &CovKeyLen. /* QC _CovKeyStrDrug _CovKeyStrMed $&DP_NumYears.*/ ;
  array CovKeyArrayDrug[&DP_StartYear.:&DP_EndYear.] $1 _temporary_;
  array CovKeyArrayMed [&DP_StartYear.:&DP_EndYear.] $1 _temporary_;
  array CovKeyArrayDrugAndMed [&DP_StartYear.:&DP_EndYear.] $1 _temporary_;
  ** Read in Prevalent_Patients dataset, by PatKey;
  set DPtemp.Prevalent_Patients;
  by PatKey;
  _YearCov=input(year,4.);
  ** For first record by PatKey initialize all elements to zeros;;
  if first.patKey then do;
    do _y=&DP_StartYear. to &DP_EndYear.;
      CovKeyArrayDrug[_y]="0";
      CovKeyArrayMed [_y]="0";
      CovKeyArrayDrugAndMed [_y]="0";
    end;
  end;
  ** For each row, file the array element, depending on the "Y" values per year, per coverage type;
  if DrugCov="Y" then CovKeyArrayDrug[_YearCov]="1";
  if MedCov= "Y" then CovKeyArrayMed[_YearCov]="1";
  if DrugCov="Y" and MedCov= "Y" then CovKeyArrayDrugAndMed[_YearCov]="1";  
  if last.PatKey then do;
    ** Create key strings for each of Drug and Med coverage and convert to a decimal value;
    CovKeyDrug=input(cat(of CovKeyArrayDrug[*]),binary&DP_NumYears..);
    CovKeyMed= input(cat(of CovKeyArrayMed[*]),binary&DP_NumYears..);
    CovKeyDrugAndMed=input(cat(of CovKeyArrayDrugAndMed[*]),binary&DP_NumYears..);
    output;
  end;
run;

** Join coverage key with PatKeys table;

proc sql _method ;
  create table DPTemp.PatKeysCovKey as
  select c.PatKey, d.PatID, d.birth_date, d.sex, 
         c.CovKeyDrug, c.CovKeyMed, c.CovKeyDrugAndMed
  from PrevPatsKey as c
          inner join 
       dptemp.PatKey (sortedby=PatKey) as d    
  on c.PatKey = d.PatKey
  where nmiss(CovKeyDrug, CovKeyMed, CovKeyDrugAndMed)=0
  order by PatKey
  ;
quit ;

* End of prev_pat_keys.sas;
