/*---------------------------------------------------------------------------------------------------*\
|   PROGRAM NAME: px_etl.sas                                                                          |
|     Extracts, filters, and transforms the MSCDM Procedure table                                     |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Version: Revised 1.0                                                                              |
|   Date: September 12, 2015                                                                          |
|                                                                                                     |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Program inputs:                                                                                   |
|       PatKey demographic table                                                                      |
|       Macro TableExtract                                                                            |
|   Program outputs:                                                                                  |
|       Multiple tables named PxYYY1, PxYYY2, PxYYY3, etc.                                            |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Contact:                                                                                          |
|       Mini-Sentinel Coordinating Center                                                             |
|       info@mini-sentinel.org                                                                        |
\*---------------------------------------------------------------------------------------------------*/

%* MOD: 10/11/15 -RR: Added filtering of ADate between DP min and max dates ;
%* MOD: 12/5/15  -RR: Created output file as view;
%* MOD: 12/8/15  -RR: Made call to CovKeyVars=CovKeyDrugAndMed;

%** Create extract of Procedure table, with these requirements:
*** 1) PX_CodeType is one of: 09, C4 or HC only and EncType is one of: AV, ED, IP, IS, or OA only
*** 2) These variables are not missing: PatID, PX, EncType, and ADate
*** 3) EncType is recoded as follows and renamed to Setting:
***    OA ==> AV
***    IS ==> IP
*** 4) Create new character variable Period, which is the year value of ADate
*** 5) Px has any periods removed and is renamed to Code;

%TableExtract(
  MSCDMTable=indata.&PROCTABLE,
  TableInVars=PatID PX_CodeType PX ADate EncType,
  EventDate=ADate,
  FilterCode=PX_CodeType in ("09" "C4" "HC")
      and EncType in ("AV" "ED" "IP" "IS" "OA")
      and CMiss(PatID, PX, PX_CodeType, EncType)=0
      and NMiss(ADate)=0
      and &DP_MinDate. <= ADate <= &DP_MaxDate.,
  TransformCode=%nrstr(
    Period=put(_Year,4.);
    Setting=ifc(EncType="OA","AV",ifc(EncType="IS","IP",EncType));
    Code=compress(Px,".");
    ),
  DemHashTable=DPTemp.Patkeyscovkey,
  HashVarKeys=PatID,
  HashVarsRead=PatKey Birth_Date Sex,
  CovKeyVars=CovKeyDrugAndMed,
  OutName=DPTemp.Px,
  OutType=V,
  TableOutVars=PatKey Code PX_CodeType Setting Period AgeTimePeriodGroupKey Sex,
  Lengths=Code $5 Setting $2,
  SplitTime=N,
  ReplaceVarPairs=%str(PatID|PatKey Px|Code)
  );

 * End of px_etl.sas;
