/*---------------------------------------------------------------------------------------------------*\
|   PROGRAM NAME: rx_drug_class_incident_episodes.sas                                                 |
|     Create incident drug class episodes for each of the lookback periods (90, 180, 270)             |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Version: Revised 1.0                                                                              |
|   Date: November 26, 2015                                                                           |
|                                                                                                     |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Program inputs:                                                                                   |
|       Multiple RX tables named rx&DrugCat.YYY1, rx&DrugCat.YYY2 etc. created by RX_ATTACH_KEYS      |
|       Rx lookup table with keys                                                                     |
|   Program outputs:                                                                                  |
|       Drug Class Incident Episodes for each of the lookback periods (90, 180, 270)                  |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Contact:                                                                                          |
|       Mini-Sentinel Coordinating Center                                                             |
|       info@mini-sentinel.org                                                                        |
\*---------------------------------------------------------------------------------------------------*/

/* Specify DrugCategory:  {GenericName | DrugClass} */
%let DrugCat = DrugClass;

*** Call macro to process dispensings to create incident episodes for each lookback period;
%Incident_Rx_Episodes
  ( InFile=DPtemp.RX&DrugCat. ,                /* Input file prefix (Note: include libname)*/
    OutFile=DPtemp.RX_&DrugCat._Epi_LookBack , /* Output file name (Note: include libname)*/
    DrugCategory=&DrugCat ,                    /* Drug Category Name: {GenericName|DrugClass}*/
    DrugCategoryKey=&DrugCat.Key ,             /* Drug Category Key: {GenericNameKey|DrugClassKey}*/
    DEBUG=&DEBUG.                              /* Y/N flag for creating extra output (Default is N)*/
   ) ;

* End of rx_drug_class_incident_episodes.sas;
