/*---------------------------------------------------------------------------------------------------*\
|   PROGRAM NAME: utility_code.sas                                                                    |
|                                                                                                     |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Version: Revised 1.0                                                                              |
|   Date: November 26, 2015                                                                           |
|                                                                                                     |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Program inputs:                                                                                   |
|       Various include files containing utility code                                                 |
|       MSCDM enrollment table                                                                        |
|   Program outputs:                                                                                  |
|       Compiled macros, formats, user functions, ready to be used                                    |
|-----------------------------------------------------------------------------------------------------|
|                                                                                                     |
|   Contact:                                                                                          |
|       Mini-Sentinel Coordinating Center                                                             |
|       info@mini-sentinel.org                                                                        |
\*---------------------------------------------------------------------------------------------------*/

/* 09/21/15 - MR: */
/*            - Add options statement to store created FCMP functions in DPTemp */
/*            - Add new calls for utility code macros and functions (updatesigfile.sas, */
/*              sigfiles_finalize.sas, numlength.sas)*/
/* 09/24/15 - MR: */
/*            - Add call to SETUP.SAS, TABLEEXTRACT.SAS, PREV_SUMM.SAS */
/* 09/29/15 - MR: */
/*            - Add call to STOCKPILE_RX.SAS */
/* 10/08/15 - MR */
/*            - Add DSN_OBS.SAS INCIDENT_RX_EPISODES.SAS CREATE_RX_EPISODE_CLAIMS.SAS */
/* 10/21/15 - MR */
/*            - Remove several individual macros and place them into ST_UTILITY_MACROS.SAS             */
/*              or UTILITY_MACROS.SAS: age_vs_period.sas, dsn_exists.sas, dsn_obs.sas,                 */
/*              inc_next.sas, NumLength.sas, retrieve_sorted_by.sas, setup.sas, sigfiles_finalize.sas, */
/*              TimeStamp.sas, UpdateSigFile.sas                                                       */
/* 11/09/15 -MR */
/*            - Breakout inc_next again due to frequent maintenance and size/complexity */

%let UTILITY_CODE = &INFOLDER.utility_code/ ;
%let UTILITY_CODE = %ms_clean_path(&UTILITY_CODE) ;

*** Set macro variable source_vs_nosource for reading in include utility programs;
%let source_vs_nosource = nosource;

*** Includes of files containing multiple "small sized" utilties;
%include "&UTILITY_CODE.qt_utility_macros.sas" /&source_vs_nosource ;   /* must include qt_utility_macros.sas first */
%include "&UTILITY_CODE.utility_macros.sas" /&source_vs_nosource ;
%include "&UTILITY_CODE.user_functions_formats.sas" /&source_vs_nosource;

*** Includes of files each containing a single utility;
%include "&UTILITY_CODE.bridge_enr_spans.sas" /&source_vs_nosource;
%include "&UTILITY_CODE.create_rx_episode_claims.sas" /&source_vs_nosource;
%include "&UTILITY_CODE.inc_next.sas" /&source_vs_nosource;
%include "&UTILITY_CODE.incident_rx_episodes.sas" /&source_vs_nosource;
%include "&UTILITY_CODE.incident_rx_summ.sas" /&source_vs_nosource;
%include "&UTILITY_CODE.prev_summ_finalize.sas" /&source_vs_nosource;
%include "&UTILITY_CODE.stockpile_rx.sas" /&source_vs_nosource;
%include "&UTILITY_CODE.rx_prev_summ.sas" /&source_vs_nosource;
%include "&UTILITY_CODE.tableextract.sas" /&source_vs_nosource;



* End of utility_code.sas ;
